Download Raw Data
================================

This tool helps to get the initial raw data from the internet to your computer.

.. code:: bash

 $ download.py --help
 usage: download.py [-h]
 
 Check if data files are here and which version they have. Contact the server
 for the latest version and update them if they are outdated.
 
 optional arguments:
   -h, --help  show this help message and exit


